/**
    Copyright 2017 Andrea "Stock" Stocchero

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

	    http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
*/
package org.pepstock.charba.client.configuration;

import org.pepstock.charba.client.options.TickMajor;

/**
 * It defines options for the major tick marks that are generated by the axis.
 * 
 * @author Andrea "Stock" Stocchero
 */
public class BaseTickMajor extends BaseTick<TickMajor> {

	/**
	 * Creates the major tick
	 * 
	 * @param axis axis instance
	 * @param configuration options element of the major tick
	 */
	BaseTickMajor(Axis axis, TickMajor configuration) {
		super(axis, configuration);
	}

	/**
	 * If <code>true</code>, major tick options are used to show major ticks.
	 * 
	 * @param enabled if <code>true</code>, major tick options are used to show major ticks
	 */
	public void setEnabled(boolean enabled) {
		getConfiguration().setEnabled(enabled);
	}

	/**
	 * If <code>true</code>, major tick options are used to show major ticks.
	 * 
	 * @return if <code>true</code>, major tick options are used to show major ticks
	 */
	public boolean isEnabled() {
		return getConfiguration().isEnabled();
	}

}
